@@ -19,9 +19,9 @@ bool FirebaseMLKit::isSupported()
 	return m_firebaseMLKitImpl->IsSupported();
 }
 
-void FirebaseMLKit::init()
+void FirebaseMLKit::init(int mode)
 {
-	m_firebaseMLKitImpl->Init();
+	m_firebaseMLKitImpl->Init(mode);
 }
 
 void FirebaseMLKit::release()
