@@ -4,6 +4,7 @@
 #include "FirebaseAuth.h"
 #include "FirebaseMessaging.h"
 #include "FirebaseRemoteConfig.h"
+#include "FirebaseMLKit.h"
 
 typedef struct {
 	PyObject_HEAD
@@ -30,8 +31,14 @@ typedef struct {
 		FirebaseRemoteConfig* firebaseRemoteConfig;
 } firebaseRemoteConfig_obj;
 
+typedef struct {
+	PyObject_HEAD
+		FirebaseMLKit* firebaseMLKit;
+} firebaseMLKit_obj;
+
 extern PyTypeObject FirebaseType;
 extern PyTypeObject FirebaseAnalyticsType;
 extern PyTypeObject FirebaseAuthType;
 extern PyTypeObject FirebaseMessagingType;
 extern PyTypeObject FirebaseRemoteConfigType;
+extern PyTypeObject FirebaseMLKitType;
