@@ -9,7 +9,7 @@ FirebaseMLKitImpl::~FirebaseMLKitImpl()
 {
 }
 
-void FirebaseMLKitImpl::Init()
+void FirebaseMLKitImpl::Init(int mode)
 {
 }
 
